@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -87,6 +87,26 @@ public final class UnifiedMailMessage extends MailMessage {
         this.delegatee = delegatee;
     }
 
+    @Override
+    public String toString() {
+        final StringBuilder builder = new StringBuilder(32);
+        builder.append("UnifiedMailMessage [");
+        {
+            final String id = getMailId();
+            if (id != null) {
+                builder.append("id=").append(id).append(", ");
+            }
+        }
+        {
+            final String folder = getFolder();
+            if (folder != null) {
+                builder.append("folder=").append(folder);
+            }
+        }
+        builder.append("]");
+        return builder.toString();
+    }
+
     @Override
     public String getMailId() {
         return mailId == null ? delegatee.getMailId() : mailId;
@@ -152,11 +172,6 @@ public final class UnifiedMailMessage extends MailMessage {
         delegatee.setContentDisposition(disposition);
     }
 
-    @Override
-    public String toString() {
-        return delegatee.toString();
-    }
-
     @Override
     public void setContentDisposition(final ContentDisposition disposition) {
         delegatee.setContentDisposition(disposition);
@@ -868,8 +883,23 @@ public final class UnifiedMailMessage extends MailMessage {
     }
 
     @Override
-    public MailPath getMailPath() {
-        return delegatee.getMailPath();
+    public int getRecentCount() {
+        return delegatee.getRecentCount();
+    }
+
+    @Override
+    public boolean containsRecentCount() {
+        return delegatee.containsRecentCount();
+    }
+
+    @Override
+    public void removeRecentCount() {
+        delegatee.removeRecentCount();
+    }
+
+    @Override
+    public void setRecentCount(final int recentCount) {
+        delegatee.setRecentCount(recentCount);
     }
 
     @Override
