@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -83,7 +83,7 @@ public final class UnifiedINBOXThreadFactory implements java.util.concurrent.Thr
         // final java.lang.SecurityManager s = System.getSecurityManager();
         // group = (s == null) ? Thread.currentThread().getThreadGroup() : s.getThreadGroup();
         this.namePrefix = namePrefix;
-        this.len = namePrefix.length() + 4;
+        len = namePrefix.length() + 4;
     }
 
     public Thread newThread(final Runnable r) {
